summaryrefslogtreecommitdiffstats
path: root/src/svnqt/client_impl.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/svnqt/client_impl.hpp')
-rw-r--r--src/svnqt/client_impl.hpp82
1 files changed, 41 insertions, 41 deletions
diff --git a/src/svnqt/client_impl.hpp b/src/svnqt/client_impl.hpp
index 4c3b363..9afc062 100644
--- a/src/svnqt/client_impl.hpp
+++ b/src/svnqt/client_impl.hpp
@@ -44,7 +44,7 @@
#pragma warning (disable: 4290)
#endif
-class QStringList;
+class TQStringList;
namespace svn
{
@@ -55,7 +55,7 @@ namespace svn
/**
* Subversion client API.
*/
- class SVNQT_NOEXPORT Client_impl:public Client
+ class SVNTQT_NOEXPORT Client_impl:public Client
{
public:
/**
@@ -96,7 +96,7 @@ namespace svn
* @param revision list specific revision when browsing remote, on working copies parameter will ignored
* @param detailed_remote if on remote listing detailed item info should get if possible
* that may slow so should configureable in frontends!
- * @return vector with Status entries.
+ * @return vector with tqStatus entries.
*/
virtual StatusEntries
status (const Path& path,
@@ -117,10 +117,10 @@ namespace svn
* @param path File to gather status.
* @param update if check against repository if new updates are there (for WC only)
* @param revision list specific revision when browsing remote, on working copies parameter will ignored
- * @return a Status with Statis.isVersioned = FALSE
+ * @return a tqStatus with Statis.isVersioned = FALSE
*/
virtual StatusPtr
- singleStatus (const Path& path,bool update=false,const Revision revision = svn::Revision::HEAD) throw (ClientException);
+ singletqStatus (const Path& path,bool update=false,const Revision revision = svn::Revision::HEAD) throw (ClientException);
/**
* Executes a revision checkout.
@@ -147,8 +147,8 @@ namespace svn
* @exception ClientException
*/
virtual void
- relocate (const Path & path, const QString &from_url,
- const QString &to_url, bool recurse) throw (ClientException);
+ relocate (const Path & path, const TQString &from_url,
+ const TQString &to_url, bool recurse) throw (ClientException);
/**
* Sets a single file for deletion.
@@ -189,11 +189,11 @@ namespace svn
* @param depth if @a path is a folder add items recursive depending on value if it. Pre-subversion 1.5 DepthInfinity is mapped to recursive, all other to not-recursive.
* @param force if true, do not error on already-versioned items.
* @param no_ignore if false don't add files or directories that match ignore patterns.
* @param add_parents if true, go up to the next versioned folder and add all between path and this folder. Used only with subversion 1.5 or newer
* @exception ClientException
* @sa svn::Depth
*/
- virtual void add (const Path & path, svn::Depth depth,bool force=false, bool no_ignore=false, bool add_parents = true) throw (ClientException);
+ virtual void add (const Path & path, svn::Depth depth,bool force=false, bool no_ignore=false, bool add_tqparents = true) throw (ClientException);
/**
* Updates the file or directory.
@@ -221,7 +221,7 @@ namespace svn
* @param peg_revision Revision to look at
* @return contents of the file
*/
- virtual QByteArray
+ virtual TQByteArray
cat (const Path & path,
const Revision & revision,
const Revision & peg_revision=svn_opt_revision_unspecified) throw (ClientException);
@@ -253,7 +253,7 @@ namespace svn
*/
virtual void
get (const Path & path,
- const QString & target,
+ const TQString & target,
const Revision & revision,
const Revision & peg_revision=svn_opt_revision_unspecified) throw (ClientException);
@@ -292,7 +292,7 @@ namespace svn
*/
virtual svn::Revision
commit (const Targets & targets,
- const QString& message,
+ const TQString& message,
svn::Depth depth,bool keep_locks=true,
const svn::StringArray&changelist=svn::StringArray(),
const PropertiesMap&revProps=PropertiesMap(),
@@ -345,12 +345,12 @@ namespace svn
* the callback asks for a logmessage.
*
* @param path
* @param message log message. if it is QString::null asks when working on repository
* @exception ClientException
*/
virtual svn::Revision
mkdir (const Path & path,
- const QString& message,
+ const TQString& message,
bool makeParent=true,
const PropertiesMap&revProps=PropertiesMap()
) throw (ClientException);
@@ -361,12 +361,12 @@ namespace svn
* the callback asks for a logmessage.
*
* @param targets encoded pathes to create
* @param message log message. if it is QString::null asks when working on repository
* @exception ClientException
*/
virtual svn::Revision
mkdir (const Targets & targets,
- const QString& message,
+ const TQString& message,
bool makeParent=true,
const PropertiesMap&revProps=PropertiesMap()
) throw (ClientException);
@@ -398,7 +398,7 @@ namespace svn
* @param overwrite overwrite existing files
* @param native_eol Either "LF", "CR" or "CRLF" or NULL.
* @param ignore_externals don't process externals definitions as part of this operation.
- * @param recurse if true, export recursively. Otherwise, export just the directory represented by from and its immediate non-directory children.
+ * @param recurse if true, export recursively. Otherwise, export just the directory represented by from and its immediate non-directory tqchildren.
*/
virtual svn_revnum_t
doExport (const Path & srcPath,
@@ -406,7 +406,7 @@ namespace svn
const Revision & revision,
const Revision & peg = Revision::UNDEFINED,
bool overwrite=false,
- const QString&native_eol=QString::null,
+ const TQString&native_eol=TQString(),
bool ignore_externals = false,
svn::Depth depth=svn::DepthInfinity
) throw (ClientException);
@@ -418,7 +418,7 @@ namespace svn
*/
virtual svn_revnum_t
doSwitch (
- const Path & path, const QString& url,
+ const Path & path, const TQString& url,
const Revision & revision,
Depth depth,
const Revision & peg=Revision::UNDEFINED,
@@ -439,8 +439,8 @@ namespace svn
* @exception ClientException
*/
virtual svn::Revision
- import (const Path & path, const QString& url,
- const QString& message,
+ import (const Path & path, const TQString& url,
+ const TQString& message,
svn::Depth depth,
bool no_ignore,bool no_unknown_nodetype,
const PropertiesMap&revProps=PropertiesMap()) throw (ClientException);
@@ -583,7 +583,7 @@ namespace svn
* @return delta between the files
* @exception ClientException
*/
- virtual QByteArray
+ virtual TQByteArray
diff_peg (const Path & tmpPath, const Path & path,const Path&relativeTo,
const Revision & revision1, const Revision & revision2, const Revision& peg_revision,
Depth depth, bool ignoreAncestry,
@@ -596,7 +596,7 @@ namespace svn
/**
* Same as other diff but extra options and changelists always set to empty list.
*/
- virtual QByteArray
+ virtual TQByteArray
diff_peg (const Path & tmpPath, const Path & path,const Path&relativeTo,
const Revision & revision1, const Revision & revision2, const Revision& peg_revision,
Depth depth, bool ignoreAncestry,
@@ -627,7 +627,7 @@ namespace svn
* @return delta between the files
* @exception ClientException
*/
- virtual QByteArray
+ virtual TQByteArray
@@ -189,11 +189,11 @@ namespace svn
* @param force if true, do not error on already-versioned items.
* @param no_ignore if false don't add files or directories that match ignore patterns.
- * @param add_parents if true, go up to the next versioned folder and add all between path and this folder. Used only with subversion 1.5 or newer
+ * @param add_tqparents if true, go up to the next versioned folder and add all between path and this folder. Used only with subversion 1.5 or newer
* @exception ClientException
* @sa svn::Depth
@@ -345,12 +345,12 @@ namespace svn
*
* @param path
- * @param message log message. if it is QString::null asks when working on repository
+ * @param message log message. if it is TQString() asks when working on repository
* @exception ClientException
*/
@@ -361,12 +361,12 @@ namespace svn
*
* @param targets encoded pathes to create
- * @param message log message. if it is QString::null asks when working on repository
+ * @param message log message. if it is TQString() asks when working on repository
* @exception ClientException
*/
diff (const Path & tmpPath, const Path & path1,const Path & path2,const Path&relativeTo,
const Revision & revision1, const Revision & revision2,
Depth depth, bool ignoreAncestry,
@@ -640,7 +640,7 @@ namespace svn
/**
* Same as other diff but extra options always set to empty list.
*/
- virtual QByteArray
+ virtual TQByteArray
diff (const Path & tmpPath, const Path & path1,const Path & path2,const Path&relativeTo,
const Revision & revision1, const Revision & revision2,
Depth depth, bool ignoreAncestry,
@@ -693,8 +693,8 @@ namespace svn
* @param recurse
* @return PathPropertiesMapList
*/
- virtual QPair<QLONG,PathPropertiesMapList>
- propget(const QString& propName,
+ virtual TQPair<TQLONG,PathPropertiesMapList>
+ propget(const TQString& propName,
const Path &path,
const Revision &revision,
const Revision &peg,
@@ -713,8 +713,8 @@ namespace svn
* @return PropertiesList
*/
virtual void
- propset(const QString& propName,
- const QString& propValue,
+ propset(const TQString& propName,
+ const TQString& propValue,
const Path &path,
Depth depth=DepthEmpty,
bool skip_check=false,
@@ -733,7 +733,7 @@ namespace svn
* @param recurse
*/
virtual void
- propdel(const QString& propName,
+ propdel(const TQString& propName,
const Path &path,
Depth depth=DepthEmpty,
bool skip_check=false,
@@ -749,7 +749,7 @@ namespace svn
* @param revision
* @return PropertiesList
*/
- virtual QPair<QLONG,PropertiesMap>
+ virtual TQPair<TQLONG,PropertiesMap>
revproplist(const Path &path,
const Revision &revision);
@@ -762,8 +762,8 @@ namespace svn
* @param revision
* @return PropertiesList
*/
- QPair<QLONG,QString>
- revpropget(const QString& propName,
+ TQPair<TQLONG,TQString>
+ revpropget(const TQString& propName,
const Path &path,
const Revision &revision);
@@ -778,9 +778,9 @@ namespace svn
* @param force
* @return Revision
*/
- virtual QLONG
- revpropset(const QString& propName,
- const QString& propValue,
+ virtual TQLONG
+ revpropset(const TQString& propName,
+ const TQString& propValue,
const Path &path,
const Revision &revision,
bool force=false);
@@ -795,8 +795,8 @@ namespace svn
* @param force
* @return Revision
*/
- virtual QLONG
- revpropdel(const QString& propName,
+ virtual TQLONG
+ revpropdel(const TQString& propName,
const Path &path,
const Revision &revision,
bool force=false);
@@ -810,7 +810,7 @@ namespace svn
*/
virtual void
lock (const Targets & targets,
- const QString& message,
+ const TQString& message,
bool steal_lock) throw (ClientException);
/**
* unlock files in repository or working copy
@@ -822,10 +822,10 @@ namespace svn
bool break_lock) throw (ClientException);
virtual void
- url2Revision(const QString&revstring,
+ url2Revision(const TQString&revstring,
Revision&start,Revision&end);
virtual void
- url2Revision(const QString&revstring,
+ url2Revision(const TQString&revstring,
Revision&start);
struct sBaton {